@@ -4,7 +4,7 @@
 	 * Does an export to the screen or as a download.  This checks to
 	 * see if they have pg_dump set up, and will use it if possible.
 	 *
-	 * $Id: dataexport.php,v 1.14.2.1 2004/06/08 01:39:04 chriskl Exp $
+	 * $Id: dataexport.php,v 1.17.2.3 2005/07/15 08:09:20 chriskl Exp $
 	 */
 
 	$extensions = array(
@@ -16,6 +16,9 @@
 		'xml' => 'xml'
 	);
 
+	// Prevent timeouts
+	if (!ini_get('safe_mode')) set_time_limit(0);
+
 	// if (!isset($_REQUEST['table']) && !isset($_REQUEST['query']))
 	// What must we do in this case? Maybe redirect to the homepage?
 
@@ -32,7 +35,7 @@
 				// instead of custom dump code
 				if ($misc->isDumpEnabled()
 						&& ($_REQUEST['d_format'] == 'copy' || $_REQUEST['d_format'] == 'sql')) {
-					$url = 'dbexport.php?database=' . urlencode($_REQUEST['database']);
+					$url = 'dbexport.php?mode=database&database=' . urlencode($_REQUEST['database']);
 					$url .= '&what=' . urlencode($_REQUEST['what']);
 					$url .= '&table=' . urlencode($_REQUEST['table']);
 					if ($data->hasSchemas()) $url .= '&schema=' . urlencode($_REQUEST['schema']);
@@ -53,7 +56,7 @@
 				// Check to see if they have pg_dump set up and if they do, use that
 				// instead of custom dump code
 				if ($misc->isDumpEnabled()) {
-					$url = 'dbexport.php?database=' . urlencode($_REQUEST['database']);
+					$url = 'dbexport.php?mode=database&database=' . urlencode($_REQUEST['database']);
 					$url .= '&what=' . urlencode($_REQUEST['what']);
 					$url .= '&table=' . urlencode($_REQUEST['table']);
 					if ($data->hasSchemas()) $url .= '&schema=' . urlencode($_REQUEST['schema']);
@@ -70,7 +73,7 @@
 				// Check to see if they have pg_dump set up and if they do, use that
 				// instead of custom dump code
 				if ($misc->isDumpEnabled()) {
-					$url = 'dbexport.php?database=' . urlencode($_REQUEST['database']);
+					$url = 'dbexport.php?mode=database&database=' . urlencode($_REQUEST['database']);
 					$url .= '&what=' . urlencode($_REQUEST['what']);
 					$url .= '&table=' . urlencode($_REQUEST['table']);
 					if ($data->hasSchemas()) $url .= '&schema=' . urlencode($_REQUEST['schema']);
@@ -93,20 +96,27 @@
 
 		// Make it do a download, if necessary
 		if ($_REQUEST['output'] == 'download') {
-			header('Content-Type: application/download');
-	
-			if (isset($extensions[$format]))
-				$ext = $extensions[$format];
-			else
-				$ext = 'txt';
-	
-			header('Content-Disposition: attachment; filename=dump.' . $ext);
+			// Set headers.  MSIE is totally broken for SSL downloading, so
+			// we need to have it download in-place as plain text
+			if (strstr($_SERVER['HTTP_USER_AGENT'], 'MSIE') && isset($_SERVER['HTTPS'])) {
+				header('Content-Type: text/plain');
+			}
+			else {
+				header('Content-Type: application/download');
+		
+				if (isset($extensions[$format]))
+					$ext = $extensions[$format];
+				else
+					$ext = 'txt';
+		
+				header('Content-Disposition: attachment; filename=dump.' . $ext);
+			}
 		}
 		else {
 			header('Content-Type: text/plain');
 		}
 	
-		if (isset($_REQUEST['query'])) $_REQUEST['query'] = trim(unserialize($_REQUEST['query']));
+		if (isset($_REQUEST['query'])) $_REQUEST['query'] = trim(urldecode($_REQUEST['query']));
 
 		// Set up the dump transaction
 		$status = $data->beginDump();
@@ -344,7 +354,7 @@
 		if (isset($_REQUEST['table'])) {
 			echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
 		}
-		echo "<input type=\"hidden\" name=\"query\" value=\"", htmlspecialchars(serialize($_REQUEST['query'])), "\" />\n";
+		echo "<input type=\"hidden\" name=\"query\" value=\"", htmlspecialchars(urlencode($_REQUEST['query'])), "\" />\n";
 		echo $misc->form;
 		echo "<input type=\"submit\" value=\"{$lang['strexport']}\" /></p>\n";
 		echo "</form>\n";
