@@ -9,9 +9,12 @@
 	 * @param $return_desc The return link name
 	 * @param $page The current page
 	 *
-	 * $Id: display.php,v 1.38 2004/05/12 22:40:49 soranzo Exp $
+	 * $Id: display.php,v 1.46.2.2 2005/03/04 02:32:44 chriskl Exp $
 	 */
 
+	// Prevent timeouts
+	if (!ini_get('safe_mode')) set_time_limit(0);
+
 	// Include application functions
 	include_once('./libraries/lib.inc.php');
 
@@ -31,7 +34,8 @@
 		$key = $_REQUEST['key'];
 
 		if ($confirm) {
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: ", $misc->printVal($_REQUEST['table']), ": {$lang['streditrow']}</h2>\n";
+			$misc->printTrail($_REQUEST['subject']);
+			$misc->printTitle($lang['streditrow']);
 			$misc->printMsg($msg);
 
 			$attrs = &$data->getTableAttributes($_REQUEST['table']);
@@ -44,7 +48,7 @@
 				echo "<table>\n<tr>";
 
 				// Output table header
-				echo "<tr><th class=\"data\">{$lang['strfield']}</th><th class=\"data\">{$lang['strtype']}</th>";
+				echo "<tr><th class=\"data\">{$lang['strcolumn']}</th><th class=\"data\">{$lang['strtype']}</th>";
 				echo "<th class=\"data\">{$lang['strformat']}</th>\n";
 				echo "<th class=\"data\">{$lang['strnull']}</th><th class=\"data\">{$lang['strvalue']}</th></tr>";
 
@@ -114,6 +118,8 @@
 			echo $misc->form;
 			if (isset($_REQUEST['table']))
 				echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
+			if (isset($_REQUEST['subject']))
+				echo "<input type=\"hidden\" name=\"subject\" value=\"", htmlspecialchars($_REQUEST['subject']), "\" />\n";
 			if (isset($_REQUEST['query']))
 				echo "<input type=\"hidden\" name=\"query\" value=\"", htmlspecialchars($_REQUEST['query']), "\" />\n";
 			if (isset($_REQUEST['count']))
@@ -156,8 +162,9 @@
 		global $lang;
 		global $PHP_SELF;
 
-		if ($confirm) { 
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: ", $misc->printVal($_REQUEST['table']), ": {$lang['strdeleterow']}</h2>\n";
+		if ($confirm) {
+			$misc->printTrail($_REQUEST['subject']);
+			$misc->printTitle($lang['strdeleterow']);
 
 			echo "<p>{$lang['strconfdeleterow']}</p>\n";
 			
@@ -166,6 +173,8 @@
 			echo $misc->form;
 			if (isset($_REQUEST['table']))
 				echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
+			if (isset($_REQUEST['subject']))
+				echo "<input type=\"hidden\" name=\"subject\" value=\"", htmlspecialchars($_REQUEST['subject']), "\" />\n";
 			if (isset($_REQUEST['query']))
 				echo "<input type=\"hidden\" name=\"query\" value=\"", htmlspecialchars($_REQUEST['query']), "\" />\n";
 			if (isset($_REQUEST['count']))
@@ -203,18 +212,24 @@
 		
 		// If current page is not set, default to first page
 		if (!isset($_REQUEST['page'])) $_REQUEST['page'] = 1;
+		
+		if (isset($_REQUEST['subject'])) {
+			$subject = $_REQUEST['subject'];
+			if (isset($_REQUEST[$subject])) $object = $_REQUEST[$subject];
+		}
 	
-		// If 'table' is not set, default to '' and set type
-		if (isset($_REQUEST['table']) && isset($_REQUEST['query'])) {
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: ", $misc->printVal($_REQUEST['table']), ": {$lang['strselect']}</h2>\n";
-			$type = 'SELECT';
-		}
-		elseif (isset($_REQUEST['table'])) {
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: ", $misc->printVal($_REQUEST['table']), ": {$lang['strbrowse']}</h2>\n";
-			$type = 'TABLE';
-		}
-		else {
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strqueryresults']}</h2>\n";
+		$misc->printTrail(isset($subject) ? $subject : 'database');
+		
+		if (isset($object)) {
+			if (isset($_REQUEST['query'])) {
+				$misc->printTitle($lang['strselect']);
+				$type = 'SELECT';
+			} else {
+				$misc->printTitle($lang['strbrowse']);
+				$type = 'TABLE';
+			}
+		} else {
+			$misc->printTitle($lang['strqueryresults']);
 			$type = 'QUERY';
 		}
 
@@ -228,25 +243,34 @@
 		if (!isset($_REQUEST['strings'])) $_REQUEST['strings'] = 'collapsed';
 	
 		// Fetch unique row identifier, if this is a table browse request.
-		if (isset($_REQUEST['table']))
-			$key = $data->getRowIdentifier($_REQUEST['table']);
+		if (isset($object))
+			$key = $data->getRowIdentifier($object);
 		else
 			$key = array();
 		
+		// Set the schema search path
+		if ($data->hasSchemas() && isset($_REQUEST['search_path'])) {
+			if ($data->setSearchPath(array_map('trim',explode(',',$_REQUEST['search_path']))) != 0) {
+				return;
+			}
+		}
+
 		// Retrieve page from query.  $max_pages is returned by reference.
 		$rs = &$data->browseQuery($type, 
-			isset($_REQUEST['table']) ? $_REQUEST['table'] : null, 
+			isset($object) ? $object : null, 
 			isset($_REQUEST['query']) ? $_REQUEST['query'] : null, 
 			$_REQUEST['sortkey'], $_REQUEST['sortdir'], $_REQUEST['page'],
 			$conf['max_rows'], $max_pages);
 	
 		// Build strings for GETs
 		$str = 	$misc->href; // . "&amp;page=" . urlencode($_REQUEST['page']);
-		if (isset($_REQUEST['table'])) $str .= "&amp;table=" . urlencode($_REQUEST['table']);
+		if (isset($object)) $str .= "&amp;" . urlencode($subject) . '=' . urlencode($object);
+		if (isset($subject)) $str .= "&amp;subject=" . urlencode($subject);
 		if (isset($_REQUEST['query'])) $str .= "&amp;query=" . urlencode($_REQUEST['query']);
 		if (isset($_REQUEST['count'])) $str .= "&amp;count=" . urlencode($_REQUEST['count']);
 		if (isset($_REQUEST['return_url'])) $str .= "&amp;return_url=" . urlencode($_REQUEST['return_url']);
 		if (isset($_REQUEST['return_desc'])) $str .= "&amp;return_desc=" . urlencode($_REQUEST['return_desc']);
+		if (isset($_REQUEST['search_path'])) $str .= "&amp;search_path=" . urlencode($_REQUEST['search_path']);
 		
 		// This string just contains sort info
 		$str2 = "sortkey=" . urlencode($_REQUEST['sortkey']) . 
@@ -274,7 +298,7 @@
 
 			$j = 0;		
 			foreach ($rs->f as $k => $v) {
-				if (isset($_REQUEST['table']) && $k == $data->id && !$conf['show_oids']) {
+				if (isset($object) && $k == $data->id && !$conf['show_oids']) {
 					$j++;
 					continue;
 				}
@@ -331,19 +355,18 @@
 					if (isset($_REQUEST['table']) && $k == $data->id && !$conf['show_oids']) continue;
 					elseif ($v !== null && $v == '') echo "<td class=\"data{$id}\">&nbsp;</td>";
 					else {
-						// Trim strings if over length
-						if ($_REQUEST['strings'] == 'collapsed' && strlen($v) > $conf['max_chars']) {
-							$v = substr($v, 0, $conf['max_chars'] - 1) . $lang['strellipsis'];
-						}
-						echo "<td class=\"data{$id}\" nowrap=\"nowrap\">", $misc->printVal($v, true, $finfo->type), "</td>";
+						echo "<td class=\"data{$id}\" nowrap=\"nowrap\">",
+							$misc->printVal($v, $finfo->type, array('null' => true, 'clip' => ($_REQUEST['strings']=='collapsed'))), "</td>";
 					}
 				}
 				echo "</tr>\n";
 				$rs->moveNext();
 				$i++;
 			}
-			echo "</table>\n";
+			echo "</table>\n";			
 			echo "<p>", $rs->recordCount(), " {$lang['strrows']}</p>\n";
+			// Show page navigation
+			$misc->printPages($_REQUEST['page'], $max_pages, "display.php?page=%s&amp;{$str}&amp;{$str2}");
 		}
 		else echo "<p>{$lang['strnodata']}</p>\n";
 
@@ -378,19 +401,26 @@
 			echo " | <a class=\"navlink\" href=\"dataexport.php?query=",
 					urlencode($_REQUEST['query']), "&amp;{$misc->href}\">{$lang['strdownload']}</a>\n";	
 		}
+
+		// Insert
+		if (isset($object) && (isset($subject) && $subject == 'table')) {
+			echo " | <a class=\"navlink\" href=\"tables.php?action=confinsertrow&amp;table=",
+				urlencode($object), "&amp;{$misc->href}\">{$lang['strinsert']}</a>\n";
+		}
+
 		// Refresh
 		echo "| <a class=\"navlink\" href=\"display.php?{$str}&amp;{$str2}&amp;strings=", urlencode($_REQUEST['strings']), 
 			"&amp;page=" . urlencode($_REQUEST['page']),
 			"\">{$lang['strrefresh']}</a></p>\n";
-				
 		echo "</p>\n";
 	}
 	
 	// If a table is specified, then set the title differently
-	if (isset($_REQUEST['table']))
+	if (isset($_REQUEST['subject']) && isset($_REQUEST[$_REQUEST['subject']]))
 		$misc->printHeader($lang['strtables']);
 	else	
 		$misc->printHeader($lang['strqueryresults']);
+
 	$misc->printBody();
 
 	switch ($action) {
