@@ -4,7 +4,7 @@
 	 * French Language file for phpPgAdmin. 
 	 * @maintainer Pascal PEYRE [pascal.peyre@cir.fr]
 	 *
-	 * $Id: french.php,v 1.12 2004/05/28 01:17:27 chriskl Exp $
+	 * $Id: french.php,v 1.14 2004/11/09 01:57:50 chriskl Exp $
 	 */
 
 	// Language and character set
@@ -12,6 +12,7 @@
 	$lang['appcharset'] = 'ISO-8859-1';
 	$lang['applocale'] = 'fr_FR';
   	$lang['appdbencoding'] = 'LATIN1';
+	$lang['applangdir'] = 'ltr';
 
 	// Basic strings
 	$lang['strintro'] = 'Bienvenue sur phpPgAdmin.';
@@ -65,6 +66,7 @@
 	$lang['strtrue'] = 'TRUE';
 	$lang['strfalse'] = 'FALSE';
         $lang['stredit']  =  'Editer';
+        $lang['strcolumn']  =  'Colonne';
 	$lang['strcolumns'] = 'Colonnes';
 	$lang['strrows'] = 'ligne(s)';
 	$lang['strrowsaff'] = 'ligne(s) affecte(s).';
@@ -91,7 +93,7 @@
 	$lang['strreindex'] = 'Reindex';
 	$lang['strrun'] = 'Lancer';
 	$lang['stradd'] = 'Ajouter';
-	$lang['strevent'] = 'Event';
+	$lang['strevent'] = 'Evnement';
 	$lang['strwhere'] = 'Where';
 	$lang['strinstead'] = 'Do Instead';
 	$lang['strwhen'] = 'When';
@@ -100,6 +102,7 @@
 	$lang['strconfirm'] = 'Confirmer';
 	$lang['strexpression'] = 'Expression';
 	$lang['strellipsis'] = '...';
+        $lang['strseparator']  =  ': ';
 	$lang['strexpand'] = 'Etendre';
 	$lang['strcollapse'] = 'Rduire';
 	$lang['strexplain'] = 'Explain';
@@ -128,6 +131,8 @@
 	$lang['strnoframes'] = 'Vous avez besoin d\'activer les frames de votre navigateur pour utiliser cette application.';
 	$lang['strbadconfig'] = 'Le fichier de configuration config.inc.php est obsolte. Vous avez besoin de le regnerer  partir de config.inc.php-dist.';
 	$lang['strnotloaded'] = 'Vous n\'avez pas compil correctement le support de la base de donnes dans votre installation de PHP.';
+        $lang['strphpversionnotsupported']  =  'Cette version de PHP n\'est pas supporte. Merci de mettre  jour PHP  la  version  %s ou ultrieure.';
+        $lang['strpostgresqlversionnotsupported']  =  'Cette Version de PostgreSQL n\'est pas supporte. Merci de mettre  jour PHP  la version %s ou ultrieure.';
 	$lang['strbadschema'] = 'Schma spcifi invalide.';
 	$lang['strbadencoding'] = 'Impossible de spcifier l\'encodage de la base de donnes.';
 	$lang['strsqlerror'] = 'Erreur SQL :';
@@ -170,11 +175,9 @@
 	$lang['strconfdeleterow'] = 'Etes-vous sr de vouloir supprimer cet enregistrement ?';
 	$lang['strrowdeleted'] = 'Enregistrement Supprim.';
 	$lang['strrowdeletedbad'] = 'Echec de suppression de l\'enregistrement.';
-	$lang['strsaveandrepeat'] = 'Sauvegarder & Rpter';
-	$lang['strfield'] = 'Champ';
-	$lang['strfields'] = 'Champs';
-	$lang['strnumfields'] = 'Nombre de Champs';
-	$lang['strfieldneedsname'] = 'Vous devez choisir un nom pour le champ.';
+        $lang['strinsertandrepeat']  =  'Inserer & Repeter';
+        $lang['strnumcols']  =  'Nombre de colonnes';
+        $lang['strcolneedsname']  =  'Vous devez spcifier un nom pour la colonne';
 	$lang['strselectallfields'] = 'Slectionner tous les champs';
         $lang['strselectneedscol']  =  'Vous devez slectionner au moins une colonne.';
         $lang['strselectunary']  =  'Oprateurs unaires ne peuvent avoir de valeurs.';
@@ -195,6 +198,8 @@
         $lang['strstructureanddata']  =  'Structure et donnes';
         $lang['strtabbed']  =  'Tabul';
         $lang['strauto']  =  'Auto';
+        $lang['strconfvacuumtable']  =  'Etes-vous sur de vouloir faire un  vacuum "%s"?';
+        $lang['strestimatedrowcount']  =  'Nombre d\'enregistrements estims';
 
 	// Users
 	$lang['struser'] = 'Utilisateur';
@@ -254,7 +259,6 @@
 	$lang['strgrantfailed'] = 'Echec de l\'octroi de privilges.';
 
 	$lang['strgrantbad'] = 'Vous devez spcifier au moins un utilisateur ou groupe et au moins un privilge.';
-	$lang['stralterprivs'] = 'Modifier Privilges(Alter)';
 	$lang['strgrantor'] = 'Grantor';
 	$lang['strasterisk'] = '*';
 	// Databases
@@ -282,6 +286,9 @@
         $lang['strfull']  =  'Intgral(Full)';
         $lang['strfreeze']  =  'Freeze';
         $lang['strforce']  =  'Forcer';
+        $lang['strsignalsent']  =  'Signal envoy.';
+        $lang['strsignalsentbad']  =  'Echec  l\'Envoi du signal.';
+        $lang['strallobjects']  =  'Tous les objets';
 
 	// Views
 	$lang['strview'] = 'Vue';
@@ -410,7 +417,9 @@
 	$lang['strshowallfunctions'] = 'Voir toutes les fonctions';
 	$lang['strnofunction'] = 'Aucune fonction trouve.';
 	$lang['strnofunctions'] = 'Aucune Fonction trouve.';
-	$lang['strcreatefunction'] = 'Crer une fonction';
+	$lang['strcreateplfunction']  =  'Crer une fonction PL/SQL';
+        $lang['strcreateinternalfunction']  =  'Crer une fonction interne';
+        $lang['strcreatecfunction']  =  'Crer une fonction C';
 	$lang['strfunctionname'] = 'Nom de la fonction';
 	$lang['strreturns'] = 'Valeur de sortie';
 	$lang['strarguments'] = 'Arguments';
@@ -424,6 +433,8 @@
 	$lang['strfunctiondroppedbad'] = 'Echech de suppression de la fonction.';
 	$lang['strfunctionupdated'] = 'Fonction mise  jour.';
 	$lang['strfunctionupdatedbad'] = 'Echec de mise  jour de la fonction.';
+        $lang['strobjectfile']  =  'Fichier Objet';
+        $lang['strlinksymbol']  =  'Symbole Lien';
 
 	// Triggers
 	$lang['strtrigger'] = 'Trigger';
@@ -449,6 +460,9 @@
 	$lang['strnotype'] = 'Aucun type trouv.';
 	$lang['strnotypes'] = 'Aucun type trouv.';
 	$lang['strcreatetype'] = 'Crer un type';
+        $lang['strcreatecomptype']  =  'Crer un type compos';
+        $lang['strtypeneedsfield']  =  'Vous devez spcifier au moins un champ.';
+        $lang['strtypeneedscols']  =  'Vous devez spcifier un nombre valide de champs.';	
 	$lang['strtypename'] = 'Nom du type';
 	$lang['strinputfn'] = 'Fonction d\'entre';
 	$lang['stroutputfn'] = 'Fonction de sortie';
@@ -457,6 +471,8 @@
 	$lang['strelement'] = 'Elment';
 	$lang['strdelimiter'] = 'Dlimiteur';
 	$lang['strstorage'] = 'Stockage';
+        $lang['strfield']  =  'Champ';
+        $lang['strnumfields']  =  'Nbre. de Champs';
 	$lang['strtypeneedsname'] = 'Vous devez indiquer un nom pour votre type.';
 	$lang['strtypeneedslen'] = 'Vous devez indiquer une longueur pour votre type.';
 	$lang['strtypecreated'] = 'Type cr';
@@ -464,6 +480,10 @@
 	$lang['strconfdroptype'] = 'Etes-vous sr de vouloir supprim le type "%s"?';
 	$lang['strtypedropped'] = 'Type supprim.';
 	$lang['strtypedroppedbad'] = 'Echec de suppression du type.';
+        $lang['strflavor']  =  'Flavor';
+	$lang['strbasetype']  =  'Base';
+	$lang['strcompositetype']  =  'Composite';
+	$lang['strpseudotype']  =  'Pseudo';
 
 	// Schemas
 	$lang['strschema'] = 'Schma';
@@ -481,6 +501,7 @@
 	$lang['strschemadroppedbad'] = 'Echec de suppression du schma.';
         $lang['strschemaaltered']  =  'Schema altered.';
         $lang['strschemaalteredbad']  =  'Schema alter failed.';
+        $lang['strsearchpath']  =  'Chemin de Recherche du Schema';
 
 	// Reports
 	$lang['strreport'] = 'Rapport';
@@ -590,9 +611,27 @@
 	$lang['strdisk']  =  'Disque';
 	$lang['strrows2']  =  'Enregistrements';
 
+	// Tablespaces
+	$lang['strtablespace']  =  'Tablespace';
+	$lang['strtablespaces']  =  'Tablespaces';
+	$lang['strshowalltablespaces']  =  'Voir tous les tablespaces';
+	$lang['strnotablespaces']  =  'Pas de tablespaces trouv.';
+	$lang['strcreatetablespace']  =  'Crer un tablespace';
+	$lang['strlocation']  =  'Location';
+	$lang['strtablespaceneedsname']  =  'Vous devez donner un nom  votre tablespace.';
+	$lang['strtablespaceneedsloc']  =  'Vous devez prciser un rpertoire dans lequel sera cr le tablespace.';
+	$lang['strtablespacecreated']  =  'Tablespace cr.';
+	$lang['strtablespacecreatedbad']  =  'Echec  la cration du Tablespace.';
+	$lang['strconfdroptablespace']  =  'Etes vous sur de vouloir supprimer le tablespace "%s"?';
+	$lang['strtablespacedropped']  =  'Tablespace supprim.';
+	$lang['strtablespacedroppedbad']  =  'Echec  la suppression du tablespace.';
+	$lang['strtablespacealtered']  =  'Tablespace modifi.';
+	$lang['strtablespacealteredbad']  =  'Echec  la modification du Tablespace.';
+
 	// Miscellaneous
 	$lang['strtopbar']  =  '%s lanc sur %s:%s -- Vous tes connect avec le profil  "%s", %s';
 	$lang['strtimefmt']  =  'jS M, Y g:iA';
 	$lang['strhelp']  =  'Aide';
+$lang['strhelpicon']  =  '?';
 
 ?>
