@@ -4,7 +4,7 @@
 	 * Japanese language file for phpPgAdmin.
 	 * @maintainer Tadashi Jokagi [elf2000@users.sourceforge.net]
 	 *
-	 * $Id: japanese.php,v 1.9.4.1 2004/06/23 05:26:00 chriskl Exp $
+	 * $Id: japanese.php,v 1.11.2.1 2005/02/09 13:18:12 chriskl Exp $
 	 */
 
 	// Language and character set
@@ -12,13 +12,14 @@
 	$lang['appcharset'] = 'EUC-JP';
 	$lang['applocale'] = 'ja_JP';
   	$lang['appdbencoding'] = 'EUC_JP';
+	$lang['applangdir'] = 'ltr';
   
 	// Welcome  
 	$lang['strintro'] = '褦phpPgAdminء';
 	$lang['strppahome'] = 'phpPgAdmin ۡڡ';
 	$lang['strpgsqlhome'] = 'PostgreSQL ۡڡ';
 	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
-	$lang['strlocaldocs'] = 'PostgreSQL ɥ (local)';
+	$lang['strlocaldocs'] = 'PostgreSQL ɥ ()';
 	$lang['strreportbug'] = 'Хݡ';
 	$lang['strviewfaq'] = 'FAQ򸫤';
 	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
@@ -63,9 +64,10 @@
 	$lang['strreferences'] = '';
 	$lang['stryes'] = 'Ϥ';
 	$lang['strno'] = '';
-	$lang['strtrue'] = '(true)';
-	$lang['strfalse'] = '(false)';
+	$lang['strtrue'] = '';
+	$lang['strfalse'] = '';
 	$lang['stredit'] = 'Խ';
+	$lang['strcolumn'] = '';
 	$lang['strcolumns'] = '';
 	$lang['strrows'] = '쥳';
 	$lang['strrowsaff'] = 'ƶ쥳';
@@ -110,15 +112,15 @@
 	$lang['stroptions'] = 'ץ';
 	$lang['strrefresh'] = 'ɽ';
 	$lang['strdownload'] = '';
-	$lang['strdownloadgzipped'] = 'gzipǰ̤ƥ';
+	$lang['strdownloadgzipped'] = 'gzip ǰ̤ƥ';
 	$lang['strinfo'] = '';
-	$lang['stroids'] = 'OID';
+	$lang['stroids'] = 'OID ';
 	$lang['stradvanced'] = '٤ʰ';
 	$lang['strvariables'] = 'ѿ';
 	$lang['strprocess'] = 'ץ';
 	$lang['strprocesses'] = 'ץ';
 	$lang['strsetting'] = '';
-	$lang['streditsql'] = 'SQLԽ';
+	$lang['streditsql'] = 'SQL Խ';
 	$lang['strruntime'] = '¹Ի: %s ms';
 	$lang['strpaginate'] = 'Paginate results';
 	$lang['struploadscript'] = 'or upload an SQL script:';
@@ -128,19 +130,19 @@
 
 	// Error handling
 	$lang['strnoframes'] = 'ΥץꥱѤ뤿ˤϥե졼बѲǽʥ֥饦ɬפǤ';
-	$lang['strbadconfig'] = 'config.inc.php켰Ǥconfig.inc.php-distƺɬפޤ';
-	$lang['strnotloaded'] = 'ǡ١򥵥ݡȤ褦PHPΥѥ롦󥹥ȡ뤬Ƥޤ(ƥˤäƤphpѥå¾php-pgsqlѥåΥ󥹥ȡ롦ʤɤɬפǤ)';
-	$lang['strphpversionnotsupported'] = 'PHPΥСϥݡȤƤޤ󡣥С %s ʾ˥åץ졼ɤƤ';
-	$lang['strpostgresqlversionnotsupported'] = 'PostgreSQLΥСϥݡȤƤޤ󡣥С %s ʾ˥åץ졼ɤƤ';
+	$lang['strbadconfig'] = 'config.inc.php 켰Ǥ config.inc.php-dist ƺɬפޤ';
+	$lang['strnotloaded'] = 'ǡ١򥵥ݡȤ褦 PHP Υѥ롦󥹥ȡ뤬Ƥޤ(ƥˤäƤ php ѥå¾ php-pgsql ѥåΥ󥹥ȡ롦ʤɤɬפǤ)';
+	$lang['strphpversionnotsupported'] = ' PHP ΥСϥݡȤƤޤ󡣥С %s ʾ˥åץ졼ɤƤ';
+	$lang['strpostgresqlversionnotsupported'] = ' PostgreSQL ΥСϥݡȤƤޤ󡣥С %s ʾ˥åץ졼ɤƤ';
 	$lang['strbadschema'] = '̵Υޤꤵޤ';
 	$lang['strbadencoding'] = 'ǡ١ǥ饤ȥ󥳡ɤꤷޤǤ';
-	$lang['strsqlerror'] = 'SQL顼:';
+	$lang['strsqlerror'] = 'SQL 顼:';
 	$lang['strinstatement'] = 'ʸ:';
 	$lang['strinvalidparam'] = 'ץȥѥ᡼̵Ǥ';
 	$lang['strnodata'] = '쥳ɤĤޤ';
 	$lang['strnoobjects'] = '֥ȤĤޤ';
 	$lang['strrownotunique'] = 'Υ쥳ɤˤϰռ̻Ҥޤ';
-	$lang['strnoreportsdb'] = 'ݡȥǡ١Ƥޤ󡣥ǥ쥯ȥˤINSTALLեɤǤ';
+	$lang['strnoreportsdb'] = 'ݡȥǡ١Ƥޤ󡣥ǥ쥯ȥˤ INSTALL եɤǤ';
 	$lang['strnouploads'] = 'ե륢åץɤ̵Ǥ';
 	$lang['strimporterror'] = 'ݡȥ顼';
 	$lang['strimporterrorline'] = '%s ܤݡȥ顼Ǥ';
@@ -175,10 +177,9 @@
 	$lang['strrowdeleted'] = '쥳ɤޤ';
 	$lang['strrowdeletedbad'] = '쥳ɤκ˼Ԥޤ';
 	$lang['strinsertandrepeat'] = 'ȷ֤';
-	$lang['strfield'] = 'ե';
-	$lang['strfields'] = 'եɰ';
-	$lang['strnumfields'] = 'եɿ';
-	$lang['strfieldneedsname'] = 'ե̾ꤹɬפޤ';
+	$lang['strnumcols'] = 'Number of columns';
+	$lang['strcolneedsname'] = 'You must specify a name for the column';
+	$lang['strtypeneedscols'] = 'You must specify a valid number of fields.';
 	$lang['strselectallfields'] = 'ƤΥեɤ';
 	$lang['strselectneedscol'] = 'ʤȤ쥫ɬפǤ';
 	$lang['strselectunary'] = 'ñΥڥ졼ͤĤȤǤޤ';
@@ -200,7 +201,8 @@
 	$lang['strstructureanddata'] = '¤ȥǡ';
 	$lang['strtabbed'] = 'Tabbed';
 	$lang['strauto'] = 'ư';
-	$lang['strsaveandrepeat'] = '¸ȷ֤';
+	$lang['strconfvacuumtable'] = ' "%s"  vacuum ޤ?';
+	$lang['strestimatedrowcount'] = 'Estimated Row Count';
 
 	// Users
 	$lang['struser'] = '桼';
@@ -260,7 +262,6 @@
 	$lang['strgranted'] = 'øͿޤ';
 	$lang['strgrantfailed'] = 'øͿ˼Ԥޤ';
 	$lang['strgrantbad'] = 'ʤȤͤΥ桼롼פˡʤȤҤȤĤøꤷʤФʤޤ';
-	$lang['stralterprivs'] = 'øѹ';
 	$lang['strgrantor'] = 'Ϳ';
 	$lang['strasterisk'] = '*';
 
@@ -289,6 +290,9 @@
 	$lang['strfull'] = '٤';
 	$lang['strfreeze'] = 'ե꡼';
 	$lang['strforce'] = '';
+	$lang['strsignalsent'] = 'ʥ';
+	$lang['strsignalsentbad'] = 'ʥ˼Ԥޤ';
+	$lang['strallobjects'] = '٤ƤΥ֥Ȱ';
 
 	// Views
 	$lang['strview'] = 'ӥ塼';
@@ -300,7 +304,7 @@
 	$lang['strviewname'] = 'ӥ塼̾';
 	$lang['strviewneedsname'] = 'ӥ塼̾ꤷʤФʤޤ';
 	$lang['strviewneedsdef'] = '̾ꤷʤФʤޤ';
-	$lang['strviewneedsfields'] = 'You must give the columns you want selected in your view.';
+	$lang['strviewneedsfields'] = 'ӥ塼Τ椫򤷡˾ΥꤷʤФʤޤ';
 	$lang['strviewcreated'] = 'ӥ塼ޤ';
 	$lang['strviewcreatedbad'] = 'ӥ塼κ˼Ԥޤ';
 	$lang['strconfdropview'] = '˥ӥ塼%sפ˴ޤ?';
@@ -417,7 +421,9 @@
 	$lang['strshowallfunctions'] = 'ؿɽ';
 	$lang['strnofunction'] = 'ؿޤ';
 	$lang['strnofunctions'] = 'ؿĤޤ';
-	$lang['strcreatefunction'] = 'ؿ';
+	$lang['strcreateplfunction'] = 'SQL/PL ؿ';
+	$lang['strcreateinternalfunction'] = 'Create internal function';
+	$lang['strcreatecfunction'] = 'C ؿ';
 	$lang['strfunctionname'] = 'ؿ̾';
 	$lang['strreturns'] = '֤';
 	$lang['strarguments'] = '';
@@ -431,6 +437,8 @@
 	$lang['strfunctiondroppedbad'] = 'ؿ˴˼Ԥޤ';
 	$lang['strfunctionupdated'] = 'ؿ򹹿ޤ';
 	$lang['strfunctionupdatedbad'] = 'ؿι˼Ԥޤ';
+	$lang['strobjectfile'] = '֥ȥե';
+	$lang['strlinksymbol'] = '󥯥ܥ';
 
 	// Triggers
 	$lang['strtrigger'] = 'ȥꥬ';
@@ -456,6 +464,9 @@
 	$lang['strnotype'] = 'ǡޤ';
 	$lang['strnotypes'] = 'ǡĤޤǤ';
 	$lang['strcreatetype'] = 'ǡκ';
+	$lang['strcreatecomptype'] = 'ʣ緿';
+	$lang['strtypeneedsfield'] = 'ʤȤ 1 ĤΥեɤꤷʤФʤޤ';
+	$lang['strtypeneedscols'] = 'ͭʥեɤοꤷʤФʤޤ';
 	$lang['strtypename'] = 'ǡ̾';
 	$lang['strinputfn'] = 'ϴؿ';
 	$lang['stroutputfn'] = 'ϴؿ';
@@ -464,6 +475,8 @@
 	$lang['strelement'] = '';
 	$lang['strdelimiter'] = 'ǥߥ꥿';
 	$lang['strstorage'] = 'ȥ졼';
+	$lang['strfield'] = 'ե';
+	$lang['strnumfields'] = 'եɿ';
 	$lang['strtypeneedsname'] = '̾ꤷʤФʤޤ';
 	$lang['strtypeneedslen'] = 'ǡĹꤷʤФʤޤ';
 	$lang['strtypecreated'] = 'ǡޤ';
@@ -471,6 +484,10 @@
 	$lang['strconfdroptype'] = '˥ǡ%sפ˴ޤ?';
 	$lang['strtypedropped'] = 'ǡ˴ޤ';
 	$lang['strtypedroppedbad'] = 'ǡ˴˼Ԥޤ';
+	$lang['strflavor'] = 'Flavor';
+	$lang['strbasetype'] = '';
+	$lang['strcompositetype'] = 'ʣ緿';
+	$lang['strpseudotype'] = 'Pseudo';
 
 	// Schemas
 	$lang['strschema'] = '';
@@ -488,6 +505,7 @@
 	$lang['strschemadroppedbad'] = 'ޤ˴˼Ԥޤ';
 	$lang['strschemaaltered'] = 'ޤѹޤ';
 	$lang['strschemaalteredbad'] = 'ޤѹ˼Ԥޤ';
+        $lang['strsearchpath'] = '޸ѥ';
 
 	// Reports
 	$lang['strreport'] = 'ݡ';
@@ -527,9 +545,9 @@
 	$lang['strcreateoperator'] = '黻Ҥޤ';
 	$lang['strleftarg'] = '';
 	$lang['strrightarg'] = '';
-	$lang['strcommutator'] = 'Commutator';
-	$lang['strnegator'] = 'Negator';
-	$lang['strrestrict'] = 'Restrict';
+	$lang['strcommutator'] = '';
+	$lang['strnegator'] = '';
+	$lang['strrestrict'] = '';
 	$lang['strjoin'] = '';
 	$lang['strhashes'] = 'ϥå';
 	$lang['strmerges'] = 'ʻ';
@@ -580,26 +598,43 @@
 	$lang['strnoopclasses'] = '黻ҥ饹Ĥޤ';
 	$lang['straccessmethod'] = 'ˡ';
 
-	// Stats & Performance
-	$lang['strrowperf'] = '쥳ɥѥեޥ';
-	$lang['strioperf'] = 'I/Oѥեޥ';
-	$lang['stridxrowperf'] = 'ǥåݡڥѥեޥ';
-	$lang['stridxioperf'] = 'ǥåI/Oѥեޥ';
+	// Stats and performance
+	$lang['strrowperf'] = 'ԥѥեޥ';
+	$lang['strioperf'] = 'I/O ѥեޥ';
+	$lang['stridxrowperf'] = 'ǥåԥѥեޥ';
+	$lang['stridxioperf'] = 'ǥå I/O ѥեޥ';
 	$lang['strpercent'] = '%';
 	$lang['strsequential'] = '󥷥';
 	$lang['strscan'] = '';
-	$lang['strread'] = 'ɤ߹';
+	$lang['strread'] = 'ɹ';
 	$lang['strfetch'] = '';
 	$lang['strheap'] = 'ҡ';
 	$lang['strtoast'] = 'TOAST';
-	$lang['strtoastindex'] = 'TOASTǥå';
+	$lang['strtoastindex'] = 'TOAST ǥå';
 	$lang['strcache'] = 'å';
 	$lang['strdisk'] = 'ǥ';
-	$lang['strrows2'] = 'Rows';
+	$lang['strrows2'] = '';
+
+	// Tablespaces
+	$lang['strtablespaces'] = 'ơ֥';
+	$lang['strtablespace'] = 'ơ֥';
+	$lang['strshowalltablespaces'] = '٤ƤΥơ֥륹ڡɽ';
+	$lang['strnotablespaces'] = 'ơ֥֤Ĥޤ';
+	$lang['strcreatetablespace'] = 'ơֺ֥';
+	$lang['strlocation'] = '';
+	$lang['strtablespaceneedsname'] = 'ơ֥̾ꤹɬפޤ';
+	$lang['strtablespaceneedsloc'] = 'ơֺ֥򤹤ǥ쥯ȥꤹɬפޤ';
+	$lang['strtablespacecreated'] = 'ơ֥֤ޤ';
+	$lang['strtablespacecreatedbad'] = 'ơ֥֤κ˼Ԥޤ';
+	$lang['strconfdroptablespace'] = '˥ơ֥֡%sפ˴ޤ?';
+	$lang['strtablespacedropped'] = 'ơ֥֤˴ޤ';
+	$lang['strtablespacedroppedbad'] = 'ơ֥֤˴˼Ԥޤ';
+	$lang['strtablespacealtered'] = 'ơ֥֤ѹޤ';
+	$lang['strtablespacealteredbad'] = 'ơ֥֤ѹ˼Ԥޤ';
 
 	// Miscellaneous
-	$lang['strtopbar'] = '%s%sݡֹ%s³Ƥޤ<br />桼%sפǥۥȡ%sפ˥󤷤Ƥޤ';
-	$lang['strtimefmt'] = 'Yǯnj G:i';
+	$lang['strtopbar'] = '%s  %s ݡֹ %s ³ -- 桼%sפǥۥȡ%sפ˥';
+	$lang['strtimefmt'] = 'Y ǯ n  j  G:i';
 	$lang['strhelp'] = 'إ';
-
+	$lang['strhelpicon'] = '?';
 ?>
