@@ -4,7 +4,7 @@
 	 * English language file for phpPgAdmin.  Use this as a basis
 	 * for new translations.
 	 *
-	 * $Id: english.php,v 1.98 2004/05/26 11:27:00 soranzo Exp $
+	 * $Id: english.php,v 1.120.2.1 2005/04/13 08:33:02 chriskl Exp $
 	 */
 
 	// Language and character set
@@ -12,6 +12,7 @@
 	$lang['appcharset'] = 'ISO-8859-1';
 	$lang['applocale'] = 'en_US';
 	$lang['appdbencoding'] = 'LATIN1';
+	$lang['applangdir'] = 'ltr';
 
 	// Welcome  
 	$lang['strintro'] = 'Welcome to phpPgAdmin.';
@@ -65,6 +66,7 @@
 	$lang['strtrue'] = 'TRUE';
 	$lang['strfalse'] = 'FALSE';
 	$lang['stredit'] = 'Edit';
+	$lang['strcolumn'] = 'Column';
 	$lang['strcolumns'] = 'Columns';
 	$lang['strrows'] = 'row(s)';
 	$lang['strrowsaff'] = 'row(s) affected.';
@@ -100,6 +102,7 @@
 	$lang['strconfirm'] = 'Confirm';
 	$lang['strexpression'] = 'Expression';
 	$lang['strellipsis'] = '...';
+	$lang['strseparator'] = ': ';
 	$lang['strexpand'] = 'Expand';
 	$lang['strcollapse'] = 'Collapse';
 	$lang['strexplain'] = 'Explain';
@@ -128,6 +131,8 @@
 	$lang['strnoframes'] = 'You need a frames-enabled browser to use this application.';
 	$lang['strbadconfig'] = 'Your config.inc.php is out of date. You will need to regenerate it from the new config.inc.php-dist.';
 	$lang['strnotloaded'] = 'Your PHP installation does not support PostgreSQL. You need to recompile PHP using the --with-pgsql configure option.';
+	$lang['strphpversionnotsupported'] = 'Version of PHP not supported. Please upgrade to version %s or later.';
+	$lang['strpostgresqlversionnotsupported'] = 'Version of PostgreSQL not supported. Please upgrade to version %s or later.';
 	$lang['strbadschema'] = 'Invalid schema specified.';
 	$lang['strbadencoding'] = 'Failed to set client encoding in database.';
 	$lang['strsqlerror'] = 'SQL error:';
@@ -140,6 +145,7 @@
 	$lang['strnouploads'] = 'File uploads are disabled.';
 	$lang['strimporterror'] = 'Import error.';
 	$lang['strimporterrorline'] = 'Import error on line %s.';
+	$lang['strcannotdumponwindows'] = 'Dumping of complex table and schema names on Windows is not supported.  Please see the FAQ.';
 
 	// Tables
 	$lang['strtable'] = 'Table';
@@ -151,7 +157,7 @@
 	$lang['strtablename'] = 'Table name';
 	$lang['strtableneedsname'] = 'You must give a name for your table.';
 	$lang['strtableneedsfield'] = 'You must specify at least one field.';
-	$lang['strtableneedscols'] = 'Tables require a valid number of columns.';
+	$lang['strtableneedscols'] = 'You must specify a valid number of columns.';
 	$lang['strtablecreated'] = 'Table created.';
 	$lang['strtablecreatedbad'] = 'Table creation failed.';
 	$lang['strconfdroptable'] = 'Are you sure you want to drop the table &quot;%s&quot;?';
@@ -170,17 +176,15 @@
 	$lang['strconfdeleterow'] = 'Are you sure you want to delete this row?';
 	$lang['strrowdeleted'] = 'Row deleted.';
 	$lang['strrowdeletedbad'] = 'Row deletion failed.';
-	$lang['strsaveandrepeat'] = 'Insert &amp; Repeat';
-	$lang['strfield'] = 'Field';
-	$lang['strfields'] = 'Fields';
-	$lang['strnumfields'] = 'Num. of fields';
-	$lang['strfieldneedsname'] = 'You must name your field.';
+	$lang['strinsertandrepeat'] = 'Insert &amp; Repeat';
+	$lang['strnumcols'] = 'Number of columns';
+	$lang['strcolneedsname'] = 'You must specify a name for the column';
 	$lang['strselectallfields'] = 'Select all fields';
 	$lang['strselectneedscol'] = 'You must show at least one column.';
 	$lang['strselectunary'] = 'Unary operators cannot have values.';
 	$lang['straltercolumn'] = 'Alter column';
 	$lang['strcolumnaltered'] = 'Column altered.';
-	$lang['strcolumnalteredbad'] = 'Column altering failed.';
+	$lang['strcolumnalteredbad'] = 'Column alteration failed.';
 	$lang['strconfdropcolumn'] = 'Are you sure you want to drop column &quot;%s&quot; from table &quot;%s&quot;?';
 	$lang['strcolumndropped'] = 'Column dropped.';
 	$lang['strcolumndroppedbad'] = 'Column drop failed.';
@@ -195,6 +199,8 @@
 	$lang['strstructureanddata'] = 'Structure and data';
 	$lang['strtabbed'] = 'Tabbed';
 	$lang['strauto'] = 'Auto';
+	$lang['strconfvacuumtable'] = 'Are you sure you want to vacuum &quot;%s&quot;?';
+	$lang['strestimatedrowcount'] = 'Estimated Row Count';
 
 	// Users
 	$lang['struser'] = 'User';
@@ -254,7 +260,6 @@
 	$lang['strgranted'] = 'Privileges changed.';
 	$lang['strgrantfailed'] = 'Failed to change privileges.';
 	$lang['strgrantbad'] = 'You must specify at least one user or group and at least one privilege.';
-	$lang['stralterprivs'] = 'Alter privileges';
 	$lang['strgrantor'] = 'Grantor';
 	$lang['strasterisk'] = '*';
 
@@ -283,6 +288,9 @@
 	$lang['strfull'] = 'Full';
 	$lang['strfreeze'] = 'Freeze';
 	$lang['strforce'] = 'Force';
+	$lang['strsignalsent'] = 'Signal sent.';
+	$lang['strsignalsentbad'] = 'Sending signal failed.';
+	$lang['strallobjects'] = 'All objects';
 
 	// Views
 	$lang['strview'] = 'View';
@@ -411,7 +419,9 @@
 	$lang['strshowallfunctions'] = 'Show all functions';
 	$lang['strnofunction'] = 'No function found.';
 	$lang['strnofunctions'] = 'No functions found.';
-	$lang['strcreatefunction'] = 'Create function';
+	$lang['strcreateplfunction'] = 'Create SQL/PL function';
+	$lang['strcreateinternalfunction'] = 'Create internal function';
+	$lang['strcreatecfunction'] = 'Create C function';
 	$lang['strfunctionname'] = 'Function name';
 	$lang['strreturns'] = 'Returns';
 	$lang['strarguments'] = 'Arguments';
@@ -425,6 +435,8 @@
 	$lang['strfunctiondroppedbad'] = 'Function drop failed.';
 	$lang['strfunctionupdated'] = 'Function updated.';
 	$lang['strfunctionupdatedbad'] = 'Function update failed.';
+	$lang['strobjectfile'] = 'Object File';
+	$lang['strlinksymbol'] = 'Link Symbol';
 
 	// Triggers
 	$lang['strtrigger'] = 'Trigger';
@@ -441,7 +453,7 @@
 	$lang['strtriggerdropped'] = 'Trigger dropped.';
 	$lang['strtriggerdroppedbad'] = 'Trigger drop failed.';
 	$lang['strtriggeraltered'] = 'Trigger altered.';
-	$lang['strtriggeralteredbad'] = 'Trigger alter failed.';
+	$lang['strtriggeralteredbad'] = 'Trigger alteration failed.';
 
 	// Types
 	$lang['strtype'] = 'Type';
@@ -450,6 +462,9 @@
 	$lang['strnotype'] = 'No type found.';
 	$lang['strnotypes'] = 'No types found.';
 	$lang['strcreatetype'] = 'Create type';
+	$lang['strcreatecomptype'] = 'Create composite type';
+	$lang['strtypeneedsfield'] = 'You must specify at least one field.';
+	$lang['strtypeneedscols'] = 'You must specify a valid number of fields.';	
 	$lang['strtypename'] = 'Type name';
 	$lang['strinputfn'] = 'Input function';
 	$lang['stroutputfn'] = 'Output function';
@@ -458,6 +473,8 @@
 	$lang['strelement'] = 'Element';
 	$lang['strdelimiter'] = 'Delimiter';
 	$lang['strstorage'] = 'Storage';
+	$lang['strfield'] = 'Field';
+	$lang['strnumfields'] = 'Num. of fields';
 	$lang['strtypeneedsname'] = 'You must give a name for your type.';
 	$lang['strtypeneedslen'] = 'You must give a length for your type.';
 	$lang['strtypecreated'] = 'Type created';
@@ -465,6 +482,10 @@
 	$lang['strconfdroptype'] = 'Are you sure you want to drop the type &quot;%s&quot;?';
 	$lang['strtypedropped'] = 'Type dropped.';
 	$lang['strtypedroppedbad'] = 'Type drop failed.';
+	$lang['strflavor'] = 'Flavor';
+	$lang['strbasetype'] = 'Base';
+	$lang['strcompositetype'] = 'Composite';
+	$lang['strpseudotype'] = 'Pseudo';
 
 	// Schemas
 	$lang['strschema'] = 'Schema';
@@ -481,7 +502,8 @@
 	$lang['strschemadropped'] = 'Schema dropped.';
 	$lang['strschemadroppedbad'] = 'Schema drop failed.';
 	$lang['strschemaaltered'] = 'Schema altered.';
-	$lang['strschemaalteredbad'] = 'Schema alter failed.';
+	$lang['strschemaalteredbad'] = 'Schema alteration failed.';
+	$lang['strsearchpath'] = 'Schema search path';
 
 	// Reports
 	$lang['strreport'] = 'Report';
@@ -508,9 +530,9 @@
 	$lang['strconfdropdomain'] = 'Are you sure you want to drop the domain &quot;%s&quot;?';
 	$lang['strdomainneedsname'] = 'You must give a name for your domain.';
 	$lang['strdomaincreated'] = 'Domain created.';
-	$lang['strdomaincreatedbad'] = 'Failed to create domain.';	
+	$lang['strdomaincreatedbad'] = 'Domain creation failed.';	
 	$lang['strdomainaltered'] = 'Domain altered.';
-	$lang['strdomainalteredbad'] = 'Failed to alter domain.';	
+	$lang['strdomainalteredbad'] = 'Domain alteration failed.';	
 
 	// Operators
 	$lang['stroperator'] = 'Operator';
@@ -591,9 +613,27 @@
 	$lang['strdisk'] = 'Disk';
 	$lang['strrows2'] = 'Rows';
 
+	// Tablespaces
+	$lang['strtablespace'] = 'Tablespace';
+	$lang['strtablespaces'] = 'Tablespaces';
+	$lang['strshowalltablespaces'] = 'Show all tablespaces';
+	$lang['strnotablespaces'] = 'No tablespaces found.';
+	$lang['strcreatetablespace'] = 'Create tablespace';
+	$lang['strlocation'] = 'Location';
+	$lang['strtablespaceneedsname'] = 'You must give a name for your tablespace.';
+	$lang['strtablespaceneedsloc'] = 'You must give a directory in which to create the tablespace.';
+	$lang['strtablespacecreated'] = 'Tablespace created.';
+	$lang['strtablespacecreatedbad'] = 'Tablespace creation failed.';
+	$lang['strconfdroptablespace'] = 'Are you sure you want to drop the tablespace &quot;%s&quot;?';
+	$lang['strtablespacedropped'] = 'Tablespace dropped.';
+	$lang['strtablespacedroppedbad'] = 'Tablespace drop failed.';
+	$lang['strtablespacealtered'] = 'Tablespace altered.';
+	$lang['strtablespacealteredbad'] = 'Tablespace alteration failed.';
+
 	// Miscellaneous
 	$lang['strtopbar'] = '%s running on %s:%s -- You are logged in as user &quot;%s&quot;, %s';
 	$lang['strtimefmt'] = 'jS M, Y g:iA';
 	$lang['strhelp'] = 'Help';
+	$lang['strhelpicon'] = '?';
 
 ?>
