@@ -4,7 +4,7 @@
 	 * Japanese language file for phpPgAdmin.
 	 * @maintainer Tadashi Jokagi [elf2000@users.sourceforge.net]
 	 *
-	 * $Id: japanese.php,v 1.9.4.1 2004/06/23 05:26:00 chriskl Exp $
+	 * $Id: japanese.php,v 1.11.2.1 2005/02/09 13:18:12 chriskl Exp $
 	 */
 
 	// Language and character set
@@ -12,13 +12,14 @@
 	$lang['appcharset'] = 'EUC-JP';
 	$lang['applocale'] = 'ja_JP';
   	$lang['appdbencoding'] = 'EUC_JP';
+	$lang['applangdir'] = 'ltr';
   
 	// Welcome  
 	$lang['strintro'] = '&#12424;&#12358;&#12371;&#12381;phpPgAdmin&#12408;&#12290;';
 	$lang['strppahome'] = 'phpPgAdmin &#12507;&#12540;&#12512;&#12506;&#12540;&#12472;';
 	$lang['strpgsqlhome'] = 'PostgreSQL &#12507;&#12540;&#12512;&#12506;&#12540;&#12472;';
 	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
-	$lang['strlocaldocs'] = 'PostgreSQL &#12489;&#12461;&#12517;&#12513;&#12531;&#12488; (local)';
+	$lang['strlocaldocs'] = 'PostgreSQL &#12489;&#12461;&#12517;&#12513;&#12531;&#12488; (&#12525;&#12540;&#12459;&#12523;)';
 	$lang['strreportbug'] = '&#12496;&#12464;&#12524;&#12509;&#12540;&#12488;';
 	$lang['strviewfaq'] = 'FAQ&#12434;&#35211;&#12427;';
 	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
@@ -63,9 +64,10 @@
 	$lang['strreferences'] = '&#21442;&#29031;';
 	$lang['stryes'] = '&#12399;&#12356;';
 	$lang['strno'] = '&#12356;&#12356;&#12360;';
-	$lang['strtrue'] = '&#30495;(true)';
-	$lang['strfalse'] = '&#20605;(false)';
+	$lang['strtrue'] = '&#30495;';
+	$lang['strfalse'] = '&#20605;';
 	$lang['stredit'] = '&#32232;&#38598;';
+	$lang['strcolumn'] = '&#12459;&#12521;&#12512;';
 	$lang['strcolumns'] = '&#12459;&#12521;&#12512;&#19968;&#35239;';
 	$lang['strrows'] = '&#12524;&#12467;&#12540;&#12489;';
 	$lang['strrowsaff'] = '&#24433;&#38911;&#12434;&#21463;&#12369;&#12383;&#12524;&#12467;&#12540;&#12489;';
@@ -110,15 +112,15 @@
 	$lang['stroptions'] = '&#12458;&#12503;&#12471;&#12519;&#12531;';
 	$lang['strrefresh'] = '&#20877;&#34920;&#31034;';
 	$lang['strdownload'] = '&#12480;&#12454;&#12531;&#12525;&#12540;&#12489;';
-	$lang['strdownloadgzipped'] = 'gzip&#12391;&#22311;&#32302;&#12375;&#12390;&#12480;&#12454;&#12531;&#12525;&#12540;&#12489;';
+	$lang['strdownloadgzipped'] = 'gzip &#12391;&#22311;&#32302;&#12375;&#12390;&#12480;&#12454;&#12531;&#12525;&#12540;&#12489;';
 	$lang['strinfo'] = '&#24773;&#22577;';
-	$lang['stroids'] = 'OID&#19968;&#35239;';
+	$lang['stroids'] = 'OID &#19968;&#35239;';
 	$lang['stradvanced'] = '&#39640;&#24230;&#12394;&#19968;&#35239;';
 	$lang['strvariables'] = '&#22793;&#25968;&#19968;&#35239;';
 	$lang['strprocess'] = '&#12503;&#12525;&#12475;&#12473;';
 	$lang['strprocesses'] = '&#12503;&#12525;&#12475;&#12473;&#19968;&#35239;';
 	$lang['strsetting'] = '&#35373;&#23450;';
-	$lang['streditsql'] = 'SQL&#32232;&#38598;';
+	$lang['streditsql'] = 'SQL &#32232;&#38598;';
 	$lang['strruntime'] = '&#32207;&#23455;&#34892;&#26178;&#38291;: %s ms';
 	$lang['strpaginate'] = 'Paginate results';
 	$lang['struploadscript'] = 'or upload an SQL script:';
@@ -128,19 +130,19 @@
 
 	// Error handling
 	$lang['strnoframes'] = '&#12371;&#12398;&#12450;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12434;&#20351;&#29992;&#12377;&#12427;&#12383;&#12417;&#12395;&#12399;&#12501;&#12524;&#12540;&#12512;&#12364;&#20351;&#29992;&#21487;&#33021;&#12394;&#12502;&#12521;&#12454;&#12470;&#12540;&#12364;&#24517;&#35201;&#12391;&#12377;&#12290;';
-	$lang['strbadconfig'] = 'config.inc.php&#12364;&#26087;&#24335;&#12391;&#12377;&#12290;&#26032;&#12375;&#12356;config.inc.php-dist&#12363;&#12425;&#20877;&#20316;&#25104;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
-	$lang['strnotloaded'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#12469;&#12509;&#12540;&#12488;&#12377;&#12427;&#12424;&#12358;&#12395;PHP&#12398;&#12467;&#12531;&#12497;&#12452;&#12523;&#12539;&#12452;&#12531;&#12473;&#12488;&#12540;&#12523;&#12364;&#12373;&#12428;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;(&#12471;&#12473;&#12486;&#12512;&#12395;&#12424;&#12387;&#12390;&#12399;php&#12497;&#12483;&#12465;&#12540;&#12472;&#12398;&#20182;&#12395;php-pgsql&#12497;&#12483;&#12465;&#12540;&#12472;&#12398;&#12452;&#12531;&#12473;&#12488;&#12540;&#12523;&#12539;&#35373;&#23450;&#12394;&#12393;&#12364;&#24517;&#35201;&#12391;&#12377;)';
-	$lang['strphpversionnotsupported'] = '&#12371;&#12398;PHP&#12398;&#12496;&#12540;&#12472;&#12519;&#12531;&#12399;&#12469;&#12509;&#12540;&#12488;&#12375;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;&#12496;&#12540;&#12472;&#12519;&#12531; %s &#20197;&#19978;&#12395;&#12450;&#12483;&#12503;&#12464;&#12524;&#12540;&#12489;&#12375;&#12390;&#12367;&#12384;&#12373;&#12356;&#12290;';
-	$lang['strpostgresqlversionnotsupported'] = '&#12371;&#12398;PostgreSQL&#12398;&#12496;&#12540;&#12472;&#12519;&#12531;&#12399;&#12469;&#12509;&#12540;&#12488;&#12375;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;&#12496;&#12540;&#12472;&#12519;&#12531; %s &#20197;&#19978;&#12395;&#12450;&#12483;&#12503;&#12464;&#12524;&#12540;&#12489;&#12375;&#12390;&#12367;&#12384;&#12373;&#12356;&#12290;';
+	$lang['strbadconfig'] = 'config.inc.php &#12364;&#26087;&#24335;&#12391;&#12377;&#12290;&#26032;&#12375;&#12356; config.inc.php-dist &#12363;&#12425;&#20877;&#20316;&#25104;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
+	$lang['strnotloaded'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#12469;&#12509;&#12540;&#12488;&#12377;&#12427;&#12424;&#12358;&#12395; PHP &#12398;&#12467;&#12531;&#12497;&#12452;&#12523;&#12539;&#12452;&#12531;&#12473;&#12488;&#12540;&#12523;&#12364;&#12373;&#12428;&#12390;&#12356;&#12414;&#12379;&#12435;(&#12471;&#12473;&#12486;&#12512;&#12395;&#12424;&#12387;&#12390;&#12399; php &#12497;&#12483;&#12465;&#12540;&#12472;&#12398;&#20182;&#12395; php-pgsql &#12497;&#12483;&#12465;&#12540;&#12472;&#12398;&#12452;&#12531;&#12473;&#12488;&#12540;&#12523;&#12539;&#35373;&#23450;&#12394;&#12393;&#12364;&#24517;&#35201;&#12391;&#12377;)&#12290;';
+	$lang['strphpversionnotsupported'] = '&#12371;&#12398; PHP &#12398;&#12496;&#12540;&#12472;&#12519;&#12531;&#12399;&#12469;&#12509;&#12540;&#12488;&#12375;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;&#12496;&#12540;&#12472;&#12519;&#12531; %s &#20197;&#19978;&#12395;&#12450;&#12483;&#12503;&#12464;&#12524;&#12540;&#12489;&#12375;&#12390;&#12367;&#12384;&#12373;&#12356;&#12290;';
+	$lang['strpostgresqlversionnotsupported'] = '&#12371;&#12398; PostgreSQL &#12398;&#12496;&#12540;&#12472;&#12519;&#12531;&#12399;&#12469;&#12509;&#12540;&#12488;&#12375;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;&#12496;&#12540;&#12472;&#12519;&#12531; %s &#20197;&#19978;&#12395;&#12450;&#12483;&#12503;&#12464;&#12524;&#12540;&#12489;&#12375;&#12390;&#12367;&#12384;&#12373;&#12356;&#12290;';
 	$lang['strbadschema'] = '&#28961;&#21177;&#12398;&#12473;&#12461;&#12540;&#12510;&#12364;&#25351;&#23450;&#12373;&#12428;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strbadencoding'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12398;&#20013;&#12391;&#12463;&#12521;&#12452;&#12450;&#12531;&#12488;&#12456;&#12531;&#12467;&#12540;&#12489;&#12434;&#25351;&#23450;&#12375;&#12414;&#12379;&#12435;&#12391;&#12375;&#12383;&#12290;';
-	$lang['strsqlerror'] = 'SQL&#12456;&#12521;&#12540;:';
+	$lang['strsqlerror'] = 'SQL &#12456;&#12521;&#12540;:';
 	$lang['strinstatement'] = '&#25991;:';
 	$lang['strinvalidparam'] = '&#12473;&#12463;&#12522;&#12503;&#12488;&#12497;&#12521;&#12513;&#12540;&#12479;&#12364;&#28961;&#21177;&#12391;&#12377;&#12290;';
 	$lang['strnodata'] = '&#12524;&#12467;&#12540;&#12489;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnoobjects'] = '&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strrownotunique'] = '&#12371;&#12398;&#12524;&#12467;&#12540;&#12489;&#12395;&#12399;&#19968;&#24847;&#35672;&#21029;&#23376;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
-	$lang['strnoreportsdb'] = '&#12524;&#12509;&#12540;&#12488;&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12364;&#20316;&#25104;&#12373;&#12428;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;&#12487;&#12451;&#12524;&#12463;&#12488;&#12522;&#12395;&#12354;&#12427;INSTALL&#12501;&#12449;&#12452;&#12523;&#12434;&#35501;&#12435;&#12391;&#12367;&#12384;&#12373;&#12356;&#12290;';
+	$lang['strnoreportsdb'] = '&#12524;&#12509;&#12540;&#12488;&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12364;&#20316;&#25104;&#12373;&#12428;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;&#12487;&#12451;&#12524;&#12463;&#12488;&#12522;&#12395;&#12354;&#12427; INSTALL &#12501;&#12449;&#12452;&#12523;&#12434;&#35501;&#12435;&#12391;&#12367;&#12384;&#12373;&#12356;&#12290;';
 	$lang['strnouploads'] = '&#12501;&#12449;&#12452;&#12523;&#12450;&#12483;&#12503;&#12525;&#12540;&#12489;&#12364;&#28961;&#21177;&#12391;&#12377;&#12290;';
 	$lang['strimporterror'] = '&#12452;&#12531;&#12509;&#12540;&#12488;&#12456;&#12521;&#12540;';
 	$lang['strimporterrorline'] = '%s &#34892;&#30446;&#12364;&#12452;&#12531;&#12509;&#12540;&#12488;&#12456;&#12521;&#12540;&#12391;&#12377;&#12290;';
@@ -175,10 +177,9 @@
 	$lang['strrowdeleted'] = '&#12524;&#12467;&#12540;&#12489;&#12434;&#21066;&#38500;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strrowdeletedbad'] = '&#12524;&#12467;&#12540;&#12489;&#12398;&#21066;&#38500;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strinsertandrepeat'] = '&#25407;&#20837;&#12392;&#32368;&#12426;&#36820;&#12375;';
-	$lang['strfield'] = '&#12501;&#12451;&#12540;&#12523;&#12489;';
-	$lang['strfields'] = '&#12501;&#12451;&#12540;&#12523;&#12489;&#19968;&#35239;';
-	$lang['strnumfields'] = '&#12501;&#12451;&#12540;&#12523;&#12489;&#25968;';
-	$lang['strfieldneedsname'] = '&#12501;&#12451;&#12540;&#12523;&#12489;&#21517;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
+	$lang['strnumcols'] = 'Number of columns';
+	$lang['strcolneedsname'] = 'You must specify a name for the column';
+	$lang['strtypeneedscols'] = 'You must specify a valid number of fields.';
 	$lang['strselectallfields'] = '&#32207;&#12390;&#12398;&#12501;&#12451;&#12540;&#12523;&#12489;&#12434;&#36984;&#25246;';
 	$lang['strselectneedscol'] = '&#23569;&#12394;&#12367;&#12392;&#12418;&#19968;&#12459;&#12521;&#12512;&#12399;&#24517;&#35201;&#12391;&#12377;&#12290;';
 	$lang['strselectunary'] = '&#21336;&#38917;&#12398;&#12458;&#12506;&#12524;&#12540;&#12479;&#12540;&#12399;&#20516;&#12434;&#25345;&#12388;&#12371;&#12392;&#12364;&#12391;&#12365;&#12414;&#12379;&#12435;&#12290;';
@@ -200,7 +201,8 @@
 	$lang['strstructureanddata'] = '&#27083;&#36896;&#12392;&#12487;&#12540;&#12479;';
 	$lang['strtabbed'] = 'Tabbed';
 	$lang['strauto'] = '&#33258;&#21205;';
-	$lang['strsaveandrepeat'] = '&#20445;&#23384;&#12392;&#32368;&#12426;&#36820;&#12375;';
+	$lang['strconfvacuumtable'] = '&#26412;&#24403;&#12395; &quot;%s&quot; &#12434; vacuum &#12375;&#12414;&#12377;&#12363;?';
+	$lang['strestimatedrowcount'] = 'Estimated Row Count';
 
 	// Users
 	$lang['struser'] = '&#12518;&#12540;&#12470;&#12540;';
@@ -260,7 +262,6 @@
 	$lang['strgranted'] = '&#29305;&#27177;&#12434;&#19982;&#12360;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strgrantfailed'] = '&#29305;&#27177;&#12434;&#19982;&#12360;&#12427;&#20107;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strgrantbad'] = '&#23569;&#12394;&#12367;&#12392;&#12418;&#19968;&#20154;&#12398;&#12518;&#12540;&#12470;&#12540;&#12363;&#12464;&#12523;&#12540;&#12503;&#12395;&#12289;&#23569;&#12394;&#12367;&#12392;&#12418;&#12402;&#12392;&#12388;&#12398;&#29305;&#27177;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
-	$lang['stralterprivs'] = '&#29305;&#27177;&#12398;&#22793;&#26356;';
 	$lang['strgrantor'] = '&#35698;&#19982;';
 	$lang['strasterisk'] = '*';
 
@@ -289,6 +290,9 @@
 	$lang['strfull'] = '&#12377;&#12409;&#12390;';
 	$lang['strfreeze'] = '&#12501;&#12522;&#12540;&#12474;';
 	$lang['strforce'] = '&#24375;&#21046;';
+	$lang['strsignalsent'] = '&#12471;&#12464;&#12490;&#12523;&#36865;&#20449;';
+	$lang['strsignalsentbad'] = '&#12471;&#12464;&#12490;&#12523;&#36865;&#20449;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;';
+	$lang['strallobjects'] = '&#12377;&#12409;&#12390;&#12398;&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#19968;&#35239;';
 
 	// Views
 	$lang['strview'] = '&#12499;&#12517;&#12540;';
@@ -300,7 +304,7 @@
 	$lang['strviewname'] = '&#12499;&#12517;&#12540;&#21517;';
 	$lang['strviewneedsname'] = '&#12499;&#12517;&#12540;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strviewneedsdef'] = '&#23450;&#32681;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
-	$lang['strviewneedsfields'] = 'You must give the columns you want selected in your view.';
+	$lang['strviewneedsfields'] = '&#12499;&#12517;&#12540;&#12398;&#12398;&#20013;&#12363;&#12425;&#36984;&#25246;&#12375;&#12289;&#24076;&#26395;&#12398;&#12459;&#12521;&#12512;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strviewcreated'] = '&#12499;&#12517;&#12540;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strviewcreatedbad'] = '&#12499;&#12517;&#12540;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strconfdropview'] = '&#26412;&#24403;&#12395;&#12499;&#12517;&#12540;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
@@ -417,7 +421,9 @@
 	$lang['strshowallfunctions'] = '&#20840;&#38306;&#25968;&#12398;&#34920;&#31034;';
 	$lang['strnofunction'] = '&#38306;&#25968;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnofunctions'] = '&#38306;&#25968;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
-	$lang['strcreatefunction'] = '&#38306;&#25968;&#20316;&#25104;';
+	$lang['strcreateplfunction'] = 'SQL/PL &#38306;&#25968;&#20316;&#25104;';
+	$lang['strcreateinternalfunction'] = 'Create internal function';
+	$lang['strcreatecfunction'] = 'C &#38306;&#25968;&#20316;&#25104;';
 	$lang['strfunctionname'] = '&#38306;&#25968;&#21517;';
 	$lang['strreturns'] = '&#36820;&#12426;&#20516;';
 	$lang['strarguments'] = '&#24341;&#25968;';
@@ -431,6 +437,8 @@
 	$lang['strfunctiondroppedbad'] = '&#38306;&#25968;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strfunctionupdated'] = '&#38306;&#25968;&#12434;&#26356;&#26032;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strfunctionupdatedbad'] = '&#38306;&#25968;&#12398;&#26356;&#26032;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strobjectfile'] = '&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12501;&#12449;&#12452;&#12523;';
+	$lang['strlinksymbol'] = '&#12522;&#12531;&#12463;&#12471;&#12531;&#12508;&#12523;';
 
 	// Triggers
 	$lang['strtrigger'] = '&#12488;&#12522;&#12460;&#12540;';
@@ -456,6 +464,9 @@
 	$lang['strnotype'] = '&#12487;&#12540;&#12479;&#22411;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnotypes'] = '&#12487;&#12540;&#12479;&#22411;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12391;&#12375;&#12383;&#12290;';
 	$lang['strcreatetype'] = '&#12487;&#12540;&#12479;&#22411;&#12398;&#20316;&#25104;';
+	$lang['strcreatecomptype'] = '&#35079;&#21512;&#22411;&#20316;&#25104;';
+	$lang['strtypeneedsfield'] = '&#23569;&#12394;&#12367;&#12392;&#12418; 1 &#12388;&#12398;&#12501;&#12451;&#12540;&#12523;&#12489;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
+	$lang['strtypeneedscols'] = '&#26377;&#21177;&#12394;&#12501;&#12451;&#12540;&#12523;&#12489;&#12398;&#25968;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strtypename'] = '&#12487;&#12540;&#12479;&#22411;&#21517;';
 	$lang['strinputfn'] = '&#20837;&#21147;&#38306;&#25968;';
 	$lang['stroutputfn'] = '&#20986;&#21147;&#38306;&#25968;';
@@ -464,6 +475,8 @@
 	$lang['strelement'] = '&#35201;&#32032;';
 	$lang['strdelimiter'] = '&#12487;&#12511;&#12522;&#12479;';
 	$lang['strstorage'] = '&#12473;&#12488;&#12524;&#12540;&#12472;';
+	$lang['strfield'] = '&#12501;&#12451;&#12540;&#12523;&#12489;';
+	$lang['strnumfields'] = '&#12501;&#12451;&#12540;&#12523;&#12489;&#25968;';
 	$lang['strtypeneedsname'] = '&#22411;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strtypeneedslen'] = '&#12487;&#12540;&#12479;&#22411;&#12398;&#38263;&#12373;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strtypecreated'] = '&#12487;&#12540;&#12479;&#22411;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
@@ -471,6 +484,10 @@
 	$lang['strconfdroptype'] = '&#26412;&#24403;&#12395;&#12487;&#12540;&#12479;&#22411;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
 	$lang['strtypedropped'] = '&#12487;&#12540;&#12479;&#22411;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strtypedroppedbad'] = '&#12487;&#12540;&#12479;&#22411;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strflavor'] = 'Flavor';
+	$lang['strbasetype'] = '&#22522;&#26412;';
+	$lang['strcompositetype'] = '&#35079;&#21512;&#22411;';
+	$lang['strpseudotype'] = 'Pseudo';
 
 	// Schemas
 	$lang['strschema'] = '&#12473;&#12461;&#12540;&#12510;';
@@ -488,6 +505,7 @@
 	$lang['strschemadroppedbad'] = '&#12473;&#12461;&#12540;&#12510;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strschemaaltered'] = '&#12473;&#12461;&#12540;&#12510;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strschemaalteredbad'] = '&#12473;&#12461;&#12540;&#12510;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
+        $lang['strsearchpath'] = '&#12473;&#12461;&#12540;&#12510;&#26908;&#32034;&#12497;&#12473;';
 
 	// Reports
 	$lang['strreport'] = '&#12524;&#12509;&#12540;&#12488;';
@@ -527,9 +545,9 @@
 	$lang['strcreateoperator'] = '&#28436;&#31639;&#23376;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strleftarg'] = '&#24038;&#24341;&#25968;&#12479;&#12452;&#12503;';
 	$lang['strrightarg'] = '&#21491;&#24341;&#25968;&#12479;&#12452;&#12503;';
-	$lang['strcommutator'] = 'Commutator';
-	$lang['strnegator'] = 'Negator';
-	$lang['strrestrict'] = 'Restrict';
+	$lang['strcommutator'] = '&#20132;&#20195;';
+	$lang['strnegator'] = '&#21542;&#23450;';
+	$lang['strrestrict'] = '&#21046;&#38480;';
 	$lang['strjoin'] = '&#32080;&#21512;';
 	$lang['strhashes'] = '&#12495;&#12483;&#12471;&#12517;';
 	$lang['strmerges'] = '&#20341;&#21512;';
@@ -580,26 +598,43 @@
 	$lang['strnoopclasses'] = '&#28436;&#31639;&#23376;&#12463;&#12521;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['straccessmethod'] = '&#12450;&#12463;&#12475;&#12473;&#26041;&#27861;';
 
-	// Stats &amp; Performance
-	$lang['strrowperf'] = '&#12524;&#12467;&#12540;&#12489;&#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
-	$lang['strioperf'] = 'I/O&#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
-	$lang['stridxrowperf'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12524;&#12509;&#12540;&#22303;&#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
-	$lang['stridxioperf'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;I/O&#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
+	// Stats and performance
+	$lang['strrowperf'] = '&#34892;&#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
+	$lang['strioperf'] = 'I/O &#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
+	$lang['stridxrowperf'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#34892;&#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
+	$lang['stridxioperf'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473; I/O &#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
 	$lang['strpercent'] = '%';
 	$lang['strsequential'] = '&#12471;&#12540;&#12465;&#12531;&#12471;&#12515;&#12523;';
-	$lang['strscan'] = '&#12473;&#12461;&#12515;&#12531;';
-	$lang['strread'] = '&#35501;&#12415;&#36796;&#12415;';
-	$lang['strfetch'] = '&#12463;&#12456;&#12522;';
+	$lang['strscan'] = '&#26908;&#32034;';
+	$lang['strread'] = '&#35501;&#36796;';
+	$lang['strfetch'] = '&#21462;&#24471;';
 	$lang['strheap'] = '&#12498;&#12540;&#12503;';
 	$lang['strtoast'] = 'TOAST';
-	$lang['strtoastindex'] = 'TOAST&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;';
+	$lang['strtoastindex'] = 'TOAST &#12452;&#12531;&#12487;&#12483;&#12463;&#12473;';
 	$lang['strcache'] = '&#12461;&#12515;&#12483;&#12471;&#12517;';
 	$lang['strdisk'] = '&#12487;&#12451;&#12473;&#12463;';
-	$lang['strrows2'] = 'Rows';
+	$lang['strrows2'] = '&#34892;';
+
+	// Tablespaces
+	$lang['strtablespaces'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;';
+	$lang['strtablespace'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;';
+	$lang['strshowalltablespaces'] = '&#12377;&#12409;&#12390;&#12398;&#12486;&#12540;&#12502;&#12523;&#12473;&#12506;&#12540;&#12473;&#12434;&#34920;&#31034;';
+	$lang['strnotablespaces'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
+	$lang['strcreatetablespace'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#20316;&#25104;';
+	$lang['strlocation'] = '&#12525;&#12465;&#12540;&#12471;&#12519;&#12531;';
+	$lang['strtablespaceneedsname'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#21517;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
+	$lang['strtablespaceneedsloc'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#20316;&#25104;&#12434;&#12377;&#12427;&#12487;&#12451;&#12524;&#12463;&#12488;&#12522;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
+	$lang['strtablespacecreated'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strtablespacecreatedbad'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strconfdroptablespace'] = '&#26412;&#24403;&#12395;&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
+	$lang['strtablespacedropped'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strtablespacedroppedbad'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strtablespacealtered'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strtablespacealteredbad'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 
 	// Miscellaneous
-	$lang['strtopbar'] = '%s&#12395;%s&#12509;&#12540;&#12488;&#30058;&#21495;%s&#12391;&#25509;&#32154;&#12375;&#12390;&#12356;&#12414;&#12377;&#12290;&lt;br /&gt;&#12518;&#12540;&#12470;&#12540;&#12300;%s&#12301;&#12391;&#12507;&#12473;&#12488;&#12300;%s&#12301;&#12395;&#12525;&#12464;&#12452;&#12531;&#12375;&#12390;&#12356;&#12414;&#12377;&#12290;';
-	$lang['strtimefmt'] = 'Y&#24180;n&#26376;j&#26085; G:i';
+	$lang['strtopbar'] = '%s &#12395; %s &#12509;&#12540;&#12488;&#30058;&#21495; %s &#12391;&#25509;&#32154; -- &#12518;&#12540;&#12470;&#12540;&#12300;%s&#12301;&#12391;&#12507;&#12473;&#12488;&#12300;%s&#12301;&#12395;&#12525;&#12464;&#12452;&#12531;';
+	$lang['strtimefmt'] = 'Y &#24180; n &#26376; j &#26085; G:i';
 	$lang['strhelp'] = '&#12504;&#12523;&#12503;';
-
+	$lang['strhelpicon'] = '?';
 ?>
