@@ -4,7 +4,7 @@
 	 * Turkish language file for phpPgAdmin.  Use this as a basis
 	 * for new translations.
 	 *
-	 * $Id: turkish.php,v 1.9 2004/05/23 02:52:50 chriskl Exp $
+	 * $Id: turkish.php,v 1.11 2004/11/09 01:57:50 chriskl Exp $
 	 */
 
 	// Language and character set
@@ -12,6 +12,7 @@
 	$lang['appcharset'] = 'ISO-8859-9';
 	$lang['applocale'] = 'tr_TR';
   	$lang['appdbencoding'] = 'LATIN5';
+	$lang['applangdir'] = 'ltr';
 
 	// Basic strings
 	$lang['strintro'] = 'phpPgAdmin\'e hogeldiniz.';
@@ -65,6 +66,7 @@
 	$lang['strtrue']  =  'TRUE';
 	$lang['strfalse']  =  'FALSE';
 	$lang['stredit'] = 'Dzenle';
+	$lang['strcolumn']  =  'KolonF';
 	$lang['strcolumns'] = 'Kolonlar';
 	$lang['strrows'] = 'satr';
 	$lang['strrowsaff']  =  'satr ilendi.';
@@ -100,6 +102,7 @@
 	$lang['strconfirm'] = 'Onayla';
 	$lang['strexpression'] = 'fade';
 	$lang['strellipsis'] = '...';
+	$lang['strseparator']  =  ': ';
 	$lang['strexpand'] = 'Genilet';
 	$lang['strcollapse']  =  'Dar grnm';
 	$lang['strexplain'] = 'Explain';
@@ -128,6 +131,8 @@
 	$lang['strnoframes']  =  'Bu uygulamay kullanabilmek icin frame destekleyen bir gzatcya gereksinmeniz bulunmaktadr.';
 	$lang['strbadconfig'] = 'config.inc.php dosyaniz gncel deil. Bu dosyay yeni config.inc.php-dist dosyasndan yaratmanz gerekmektedir.';
 	$lang['strnotloaded'] = 'PHP kurulumunuzda PostgreSQL destei bulunamamtr.';
+	$lang['strphpversionnotsupported'] = 'Bu PHP srm desteklenmemektedir. Ltfen %s ya da st bir srme gncelleyiniz.';
+        $lang['strpostgresqlversionnotsupported'] = 'Bu PostgreSQL srm desteklenmemektedir. Ltfen %s ya da st bir srme gncelleyiniz.';
 	$lang['strbadschema'] = 'Geersiz ema.';
 	$lang['strbadencoding'] = 'stemci dil kodlamasn ayarlamaya alrken bir hata olutu.';
 	$lang['strsqlerror'] = 'SQL hatas:';
@@ -170,11 +175,9 @@
 	$lang['strconfdeleterow'] = 'Bu kayd silmek istediinize emin misiniz?';
 	$lang['strrowdeleted'] = 'Kayt silindi.';
 	$lang['strrowdeletedbad'] = 'Kayt silinme ilemi baarsz oldu.';
-	$lang['strsaveandrepeat'] = 'Kaydet ve tekrarla';
-	$lang['strfield'] = 'Alan';
-	$lang['strfields'] = 'Alanlar';
-	$lang['strnumfields'] = 'Alan says';
-	$lang['strfieldneedsname'] = 'Alan ksmna ad vermelisiniz';
+        $lang['strinsertandrepeat'] = 'Ekle ve Tekrarla';
+        $lang['strnumcols'] = 'Kolon says';
+        $lang['strcolneedsname'] = 'Kolon iin bir ad vermelisiniz.';
 	$lang['strselectallfields']  =  'Tm alanlar se';
 	$lang['strselectneedscol'] = 'En az bir kolon iaretlemelisiniz';
 	$lang['strselectunary']  =  'Unary operatrlerin deeri olamaz.';
@@ -195,6 +198,8 @@
 	$lang['strstructureanddata']  =  'Yap ve veri';
 	$lang['strtabbed']  =  'Tabbed';
 	$lang['strauto']  =  'Otomatik';
+	$lang['strconfvacuumtable'] = '"%s" tablosunu vakumlamak istediiniz emin misiniz?';
+        $lang['strestimatedrowcount'] = 'Yaklak satr says';
 
 	// Users
 	$lang['struser'] = 'Kullanc';
@@ -255,7 +260,6 @@
 	$lang['strgrantfailed'] = 'zinlerin grant ilemi baarsz oldu.';
 
 	$lang['strgrantbad'] = 'En az bir kullanc ya da grup ve en az bir izin belirtmelisiniz.';
-	$lang['stralterprivs']  =  'zinleri deitir.';
 	$lang['strgrantor'] = 'Grantor';
 	$lang['strasterisk'] = '*';
 
@@ -284,6 +288,9 @@
 	$lang['strfull']  =  'Full';
 	$lang['strfreeze']  =  'Freeze';
 	$lang['strforce']  =  'Force';
+	$lang['strsignalsent'] = 'Sinyal gnderildi.';
+        $lang['strsignalsentbad'] = 'Sinyal gnderme ilemi baarsz oldu';
+        $lang['strallobjects'] = 'Tm nesneler';
 
 	// Views
 	$lang['strview'] = 'View';
@@ -303,7 +310,7 @@
 	$lang['strviewdroppedbad'] = 'View kaldrma ilemi baarsz oldu.';
 	$lang['strviewupdated'] = 'View gncellendi.';
 	$lang['strviewupdatedbad'] = 'View gncelleme ilemi baarsz oldu.';
-$lang['strviewlink']  =  'Linking Keys';
+	$lang['strviewlink']  =  'Linking Keys';
 	$lang['strviewconditions']  =  'Ek durumlar';
 	$lang['strcreateviewwiz']  =  'Sihirbaz ile view yaratn';
 
@@ -412,7 +419,9 @@ $lang['strviewlink']  =  'Linking Keys';
 	$lang['strshowallfunctions'] = 'Tm fonksiyonlar gster';
 	$lang['strnofunction'] = 'Fonksiyon bulunamad.';
 	$lang['strnofunctions'] = 'Fonksiyon bulunamad.';
-	$lang['strcreatefunction'] = 'Fonksiyon yarat';
+	$lang['strcreateplfunction'] = 'SQL/PL fonksiyonu yarat';
+        $lang['strcreateinternalfunction'] = ' (internal) fonksiyon yarat';
+        $lang['strcreatecfunction'] = 'C fonksiyonu yarat';
 	$lang['strfunctionname'] = 'Fonksiyon ad';
 	$lang['strreturns'] = 'Dnderilen deer';
 	$lang['strarguments'] = 'Argmanlar';
@@ -426,6 +435,8 @@ $lang['strviewlink']  =  'Linking Keys';
 	$lang['strfunctiondroppedbad'] = 'Fonksiyon kaldrma ilemi baarsz oldu.';
 	$lang['strfunctionupdated'] = 'Fonksiyon gncellendi.';
 	$lang['strfunctionupdatedbad'] = 'Function gncelleme ilemi baarsz oldu.';
+	$lang['strobjectfile'] = 'Nesne dosyas';
+        $lang['strlinksymbol'] = 'Balant sembol';
 
 	// Triggers
 	$lang['strtrigger'] = 'Trigger';
@@ -451,6 +462,9 @@ $lang['strviewlink']  =  'Linking Keys';
 	$lang['strnotype'] = 'Hi veri tipi bulunamad.';
 	$lang['strnotypes'] = 'Hi veri tipi bulunamad.';
 	$lang['strcreatetype'] = 'Yeni veri tipi yarat';
+        $lang['strcreatecomptype'] = 'Karmak veri tipi yarat';
+        $lang['strtypeneedsfield'] = 'En az bir alan belirtmelisiniz.';
+        $lang['strtypeneedscols'] = 'Geerli bir alan says belirtmelisiniz.';
 	$lang['strtypename'] = 'Veri tipi ad';
 	$lang['strinputfn'] = 'Giri (Input) fonksiyonu';
 	$lang['stroutputfn'] = 'k (Output) fonksiyonu';
@@ -459,6 +473,9 @@ $lang['strviewlink']  =  'Linking Keys';
 	$lang['strelement'] = 'Eleman';
 	$lang['strdelimiter'] = 'Delimiter';
 	$lang['strstorage'] = 'Storage';
+	$lang['strfield']  =  'Alan';
+	$lang['strnumfields']  =  'Alanlarn says';
+
 	$lang['strtypeneedsname'] = 'Veri tipi iin bir ad vermelisiniz.';
 	$lang['strtypeneedslen'] = 'Veri tipiniz iin bir uzunluk belirtmelisiniz.';
 	$lang['strtypecreated'] = 'Veri tipi yaratld';
@@ -466,6 +483,10 @@ $lang['strviewlink']  =  'Linking Keys';
 	$lang['strconfdroptype'] = '"%s" veri tipini kaldrmak istediinize emin misiniz?';
 	$lang['strtypedropped'] = 'Veri tipi kaldrld.';
 	$lang['strtypedroppedbad'] = 'Veri tipi kaldrlamad.';
+        $lang['strflavor'] = 'Flavor';
+        $lang['strbasetype'] = 'Base';
+        $lang['strcompositetype'] = 'Composite';
+        $lang['strpseudotype'] = 'Pseudo';
 
 	// Schemas
 	$lang['strschema'] = 'ema';
@@ -483,6 +504,7 @@ $lang['strviewlink']  =  'Linking Keys';
 	$lang['strschemadroppedbad'] = 'ema kaldrma ilemi baarsz oldu.';
 	$lang['strschemaaltered']  =  'Schema deitirildi.';
 	$lang['strschemaalteredbad']  =  'Schema deitirilme ilemi baarsz oldu.';
+	$lang['strsearchpath'] = 'ema arama yolu';
 
 	// Reports
 	$lang['strreport'] = 'Rapor';
@@ -585,9 +607,28 @@ $lang['strviewlink']  =  'Linking Keys';
 	$lang['strdisk'] = 'Disk';
 	$lang['strrows2'] = 'Rows';
 
+	// Tablespaces
+	$lang['strtablespace'] = 'Tablespace';
+	$lang['strtablespaces'] = 'Tablespaceler';
+	$lang['strshowalltablespaces'] = 'Tm tablespaceleri gster';
+	$lang['strnotablespaces'] = 'Hi tablespace bulunamad.';
+	$lang['strcreatetablespace'] = 'Tablespace yarat';
+	$lang['strlocation'] = 'Yer';
+	$lang['strtablespaceneedsname'] = 'Tablespace\'e bir ad vermelisiniz.';
+	$lang['strtablespaceneedsloc'] = 'Tablespace\'in yaratlaca dizini belirtmelisiniz';
+	$lang['strtablespacecreated'] = 'Tablespace yaratld.';
+	$lang['strtablespacecreatedbad'] = 'Tablespace yaratlamad.';
+	$lang['strconfdroptablespace'] = '"%s" adl tablespace\'i kaldrmak istediinize emin misiniz?';
+	$lang['strtablespacedropped'] = 'Tablespace kaldrld.';
+	$lang['strtablespacedroppedbad'] = 'Tablespace kaldrlamad.';
+	$lang['strtablespacealtered'] = 'Tablespace deitirildi.';
+	$lang['strtablespacealteredbad'] = 'Tablespace deitirilemedi.';
+
 	// Miscellaneous
 	$lang['strtopbar']  =  '%s, %s:%s zerinde alyor-- "%s", %s kullancs ile sisteme giri yaptnz.';
-	$lang['strtimefmt']  =  'jS M, Y g:iA';
-	$lang['strhelp']  =  'Yardm';
+        $lang['strtimefmt']  =  'jS M, Y g:iA';
+        $lang['strhelp']  =  'Yardm';
+	$lang['strhelpicon'] = '?';
 
 ?>
+
